@@ -119,20 +119,22 @@ def add_to_recent(uri):
 		manager = gtk.recent_manager_get_default()
 		manager.add_item(uri)
 
-def url_show_file(url):
+def url_show_file(url, escape=True):
 	try:
-		uri = gnomevfs.escape_host_and_path_string(url)
-		gnomevfs.url_show(uri)
-		add_to_recent(uri)
+		if escape:
+			url = gnomevfs.escape_host_and_path_string(url)
+		gnomevfs.url_show(url)
+		add_to_recent(url)
 	except Exception, e:
 		executed = False
 		try:
 			executed = spawn_async([gnomevfs.get_local_path_from_uri(url)])
 		except:
 			if not executed:
-				uri = gnomevfs.escape_host_and_path_string(dirname(url))
-				url_show(uri)
-				add_to_recent(uri)
+				if escape:
+					url = gnomevfs.escape_host_and_path_string(dirname(url))
+				url_show(url)
+				add_to_recent(url)
 
 def url_show(url):
 	try:
